@@ -57,6 +57,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.lang.annotation.Annotation;
 import java.lang.ref.SoftReference;
+import java.lang.ref.WeakReference;
 import java.util.concurrent.ConcurrentHashMap;
 import javax.management.*;
 
@@ -81,7 +82,7 @@ public class SerializerFactory extends AbstractSerializerFactory
     = new WeakHashMap<ClassLoader,SoftReference<SerializerFactory>>();
 
   private ContextSerializerFactory _contextFactory;
-  private ClassLoader _loader;
+  private WeakReference<ClassLoader> _loaderRef;
 
   protected Serializer _defaultSerializer;
 
@@ -109,7 +110,7 @@ public class SerializerFactory extends AbstractSerializerFactory
 
   public SerializerFactory(ClassLoader loader)
   {
-    _loader = loader;
+    _loaderRef = new WeakReference<ClassLoader>(loader);
 
     _contextFactory = ContextSerializerFactory.create(loader);
   }
@@ -141,7 +142,7 @@ public class SerializerFactory extends AbstractSerializerFactory
 
   public ClassLoader getClassLoader()
   {
-    return _loader;
+    return _loaderRef.get();
   }
 
   /**
@@ -231,7 +232,7 @@ public class SerializerFactory extends AbstractSerializerFactory
     return serializer;
   }
 
-  protected Serializer loadSerializer(Class cl)
+  protected Serializer loadSerializer(Class<?> cl)
     throws HessianProtocolException
   {
     Serializer serializer = null;
@@ -277,7 +278,7 @@ public class SerializerFactory extends AbstractSerializerFactory
     else if (JavaSerializer.getWriteReplace(cl) != null) {
       Serializer baseSerializer = getDefaultSerializer(cl);
       
-      return new WriteReplaceSerializer(cl, _loader, baseSerializer);
+      return new WriteReplaceSerializer(cl, getClassLoader(), baseSerializer);
     }
 
     else if (Map.class.isAssignableFrom(cl)) {
@@ -415,26 +416,29 @@ public class SerializerFactory extends AbstractSerializerFactory
     if (Collection.class.isAssignableFrom(cl))
       deserializer = new CollectionDeserializer(cl);
 
-    else if (Map.class.isAssignableFrom(cl))
+    else if (Map.class.isAssignableFrom(cl)) {
       deserializer = new MapDeserializer(cl);
-
-    else if (Annotation.class.isAssignableFrom(cl))
+    }
+    else if (Iterator.class.isAssignableFrom(cl)) {
+      deserializer = IteratorDeserializer.create();
+    }
+    else if (Annotation.class.isAssignableFrom(cl)) {
       deserializer = new AnnotationDeserializer(cl);
-
-    else if (cl.isInterface())
+    }
+    else if (cl.isInterface()) {
       deserializer = new ObjectDeserializer(cl);
-
-    else if (cl.isArray())
+    }
+    else if (cl.isArray()) {
       deserializer = new ArrayDeserializer(cl.getComponentType());
-
-    else if (Enumeration.class.isAssignableFrom(cl))
+    }
+    else if (Enumeration.class.isAssignableFrom(cl)) {
       deserializer = EnumerationDeserializer.create();
-
+    }
     else if (Enum.class.isAssignableFrom(cl))
       deserializer = new EnumDeserializer(cl);
 
     else if (Class.class.equals(cl))
-      deserializer = new ClassDeserializer(_loader);
+      deserializer = new ClassDeserializer(getClassLoader());
 
     else
       deserializer = getDefaultDeserializer(cl);
@@ -663,10 +667,10 @@ public class SerializerFactory extends AbstractSerializerFactory
     }
     else {
       try {
-        Class cl = Class.forName(type, false, _loader);
+        Class cl = Class.forName(type, false, getClassLoader());
         deserializer = getDeserializer(cl);
       } catch (Exception e) {
-        log.warning("Hessian/Burlap: '" + type + "' is an unknown class in " + _loader + ":\n" + e);
+        log.warning("Hessian/Burlap: '" + type + "' is an unknown class in " + getClassLoader() + ":\n" + e);
 
         log.log(Level.FINER, e.toString(), e);
       }
@@ -704,6 +708,7 @@ public class SerializerFactory extends AbstractSerializerFactory
     addBasic(Double.class, "double", BasicSerializer.DOUBLE);
     addBasic(Character.class, "char", BasicSerializer.CHARACTER_OBJECT);
     addBasic(String.class, "string", BasicSerializer.STRING);
+    addBasic(StringBuilder.class, "string", BasicSerializer.STRING_BUILDER);
     addBasic(Object.class, "object", BasicSerializer.OBJECT);
     addBasic(java.util.Date.class, "date", BasicSerializer.DATE);
 
